![GitLab tag (self-managed)](https://img.shields.io/gitlab/v/tag/eclipse%2Fxfsc%2Ftsa%2Finfohub?gitlab_url=https%3A%2F%2Fgitlab.eclipse.org&logo=gitlab&label=Latest%20Eclipse%20Tag)

![GitLab tag (self-managed)](https://img.shields.io/gitlab/v/tag/gaiax%2Ftsa%2Finfohub-helm?gitlab_url=https%3A%2F%2Fcode.vereign.com&logo=gitlab&label=Latest%20Local%20Tag&labelColor=grey&color=orange)

# infohub

## Deployment

The pipeline in this repo builds image from the source code repo in eclipse as a submodule in `app/`. It also packages and pushes the helm chart and triggers manual deployment to `dev-ssi` or `prod-ssi(vault)`

### From main branch

When changes to helm or the app are made and deployment is needed, execute the following steps:

1. Edit `Chart.yaml` with the new chart version (example: 1.4.3) and app version it's intended to use (example: v1.4.3).
2. Create merge request from the update branch.
3. Create a new tag from main branch with the intended chart version (1.4.3)
4. Wait for pipelines to finish and manually trigger deployment to either `dev-ssi` or `prod-ssi(vault)` clusters.

## Values

| Key                                                               | Type   | Default                                                                                      | Description                                                    |
| ----------------------------------------------------------------- | ------ | -------------------------------------------------------------------------------------------- | -------------------------------------------------------------- |
| addresses.cache                                                   | string | `"http://cache:8080"`                                                                        |                                                                |
| addresses.issuerUri                                               | string | `"did:web:123"`                                                                              |                                                                |
| addresses.policy                                                  | string | `"http://policy:8080"`                                                                       |                                                                |
| addresses.signer                                                  | string | `"http://signer:8080"`                                                                       |                                                                |
| autoscaling.enabled                                               | bool   | `false`                                                                                      | Enable autoscaling                                             |
| autoscaling.maxReplicas                                           | int    | `3`                                                                                          | Maximum replicas                                               |
| autoscaling.minReplicas                                           | int    | `1`                                                                                          | Minimum replicas                                               |
| autoscaling.targetCPUUtilizationPercentage                        | int    | `70`                                                                                         | CPU target for autoscaling trigger                             |
| autoscaling.targetMemoryUtilizationPercentage                     | int    | `70`                                                                                         | Memory target for autoscaling trigger                          |
| image.name                                                        | string | `"gaiax/infohub"`                                                                            | Image name                                                     |
| image.pullPolicy                                                  | string | `"IfNotPresent"`                                                                             | Image pull policy                                              |
| image.pullSecrets                                                 | string | `"deployment-key-light"`                                                                     | Image pull secret when internal image is used                  |
| image.repository                                                  | string | `"eu.gcr.io/vrgn-infra-prj"`                                                                 |                                                                |
| image.sha                                                         | string | `""`                                                                                         | Image sha, usually generated by the CI Uses image.tag if empty |
| image.tag                                                         | string | `""`                                                                                         | Image tag Uses .Chart.AppVersion if empty                      |
| infohub.http.host                                                 | string | `""`                                                                                         |                                                                |
| infohub.http.port                                                 | int    | `8080`                                                                                       |                                                                |
| infohub.http.timeout.idle                                         | string | `"120s"`                                                                                     |                                                                |
| infohub.http.timeout.read                                         | string | `"10s"`                                                                                      |                                                                |
| infohub.http.timeout.write                                        | string | `"10s"`                                                                                      |                                                                |
| ingress.annotations."cert-manager.io/cluster-issuer"              | string | `"letsencrypt-production-http"`                                                              |                                                                |
| ingress.annotations."kubernetes.io/ingress.class"                 | string | `"nginx"`                                                                                    |                                                                |
| ingress.annotations."kubernetes.io/ingress.global-static-ip-name" | string | `"dev-light-public"`                                                                         |                                                                |
| ingress.annotations."nginx.ingress.kubernetes.io/rewrite-target"  | string | `"/$2"`                                                                                      |                                                                |
| ingress.enabled                                                   | bool   | `true`                                                                                       |                                                                |
| ingress.frontendDomain                                            | string | `"gaiax.vereign.com"`                                                                        |                                                                |
| ingress.frontendTlsSecretName                                     | string | `"cert-manager-tls"`                                                                         |                                                                |
| ingress.tlsEnabled                                                | bool   | `true`                                                                                       |                                                                |
| log.encoding                                                      | string | `"json"`                                                                                     |                                                                |
| log.level                                                         | string | `"debug"`                                                                                    |                                                                |
| metrics.enabled                                                   | bool   | `true`                                                                                       | Enable prometheus metrics                                      |
| metrics.port                                                      | int    | `2112`                                                                                       | Port for prometheus metrics                                    |
| mongo.addr                                                        | string | `"mongodb://mongodb-mongodb-replicaset.mongo:27017/infohub?replicaSet=rs0&authSource=admin"` |                                                                |
| mongo.dbname                                                      | string | `"infohub"`                                                                                  |                                                                |
| mongo.pass                                                        | string | `""`                                                                                         |                                                                |
| mongo.user                                                        | string | `""`                                                                                         |                                                                |
| name                                                              | string | `"infohub"`                                                                                  | Application name                                               |
| nameOverride                                                      | string | `""`                                                                                         | Ovverwrites application name                                   |
| podAnnotations                                                    | object | `{}`                                                                                         |                                                                |
| replicaCount                                                      | int    | `1`                                                                                          | Default number of instances to start                           |
| resources.limits.cpu                                              | string | `"150m"`                                                                                     |                                                                |
| resources.limits.memory                                           | string | `"128Mi"`                                                                                    |                                                                |
| resources.requests.cpu                                            | string | `"25m"`                                                                                      |                                                                |
| resources.requests.memory                                         | string | `"64Mi"`                                                                                     |                                                                |
| security.runAsGid                                                 | int    | `0`                                                                                          | Group used by the apps                                         |
| security.runAsNonRoot                                             | bool   | `false`                                                                                      | by default, apps run as non-root                               |
| security.runAsUid                                                 | int    | `0`                                                                                          | User used by the apps                                          |
| service.port                                                      | int    | `8080`                                                                                       |                                                                |

---

Autogenerated from chart metadata using [helm-docs v1.10.0](https://github.com/norwoodj/helm-docs/releases/v1.10.0)
